@@ -1,8 +1,7 @@
-/*  Note: You are free to use whatever license you want.
-    Eventually you will be able to edit it within Glade. */
-
 /*  cheatah
- *  Copyright (C) <YEAR> <AUTHORS>
+ *  Copyright (C) 1999, CrossWire Bible Society
+ *			P. O. Box 2528
+ *			Tempe, AZ  85280-2528
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -65,9 +64,10 @@ set_notebook_tab                       (GtkWidget       *notebook,
 
 MainWindow::MainWindow() {
 	searchType_group = NULL;
-	mainMgr = new SWMgr();
-	curMod = NULL;
-	chapDisplay = 0;	// set in create
+	mainMgr          = new SWMgr();
+	curMod           = NULL;
+	chapDisplay      = 0;	// set in create
+	entryDisplay     = 0;	// set in create
 }
 
 
@@ -75,6 +75,8 @@ MainWindow::~MainWindow() {
 	delete mainMgr;
 	if (chapDisplay)
 		delete chapDisplay;
+	if (entryDisplay)
+		delete entryDisplay;
 }
 
 
@@ -148,6 +150,23 @@ GtkWidget *MainWindow::create() {
   gtk_object_set_data (GTK_OBJECT (mainWindow), "menuView", menuView);
   gtk_menu_item_set_submenu (GTK_MENU_ITEM (View3), menuView);
 
+  commentaries = gtk_menu_item_new_with_label ("Commentaries");
+  gtk_object_set_data (GTK_OBJECT (mainWindow), "commentaries", commentaries);
+  gtk_widget_show (commentaries);
+
+  menuCommentaries = gtk_menu_new ();
+  gtk_object_set_data (GTK_OBJECT (mainWindow), "menuCommentaries", menuCommentaries);
+  gtk_menu_item_set_submenu (GTK_MENU_ITEM (commentaries), menuCommentaries);
+
+  dictionaries = gtk_menu_item_new_with_label ("Dictionaries");
+  gtk_object_set_data (GTK_OBJECT (mainWindow), "Dictionaries", dictionaries);
+  gtk_widget_show (dictionaries);
+
+  menuDictionaries = gtk_menu_new ();
+  gtk_object_set_data (GTK_OBJECT (mainWindow), "menuDictionaries", menuDictionaries);
+  gtk_menu_item_set_submenu (GTK_MENU_ITEM (dictionaries), menuDictionaries);
+
+
 
   Help = gtk_menu_item_new_with_label ("Help");
   gtk_object_set_data (GTK_OBJECT (mainWindow), "Help", Help);
@@ -200,24 +219,42 @@ GtkWidget *MainWindow::create() {
   gtk_widget_show (hbox2);
   gtk_box_pack_start (GTK_BOX (mainPanel), hbox2, TRUE, TRUE, 0);
 
+
+/*
+  textScrolledWindow = gtk_scrolled_window_new (NULL, NULL);
+  gtk_object_set_data (GTK_OBJECT (mainWindow), "textScrolledWindow", textScrolledWindow);
+  gtk_widget_show (textScrolledWindow);
+  gtk_box_pack_start (GTK_BOX (hbox2), textScrolledWindow, FALSE, FALSE, 0);
+*/
+
   moduleText = gtk_text_new (NULL, NULL);
   gtk_object_set_data (GTK_OBJECT (mainWindow), "moduleText", moduleText);
   gtk_widget_show (moduleText);
+//  gtk_container_add (GTK_CONTAINER (textScrolledWindow), moduleText);
   gtk_box_pack_start (GTK_BOX (hbox2), moduleText, TRUE, TRUE, 0);
   gtk_text_set_editable (GTK_TEXT (moduleText), FALSE);
   gtk_text_set_word_wrap (GTK_TEXT (moduleText), TRUE);
   gtk_widget_realize (moduleText);
 
+	/* Add a vertical scrollbar to the GtkText widget */
+	textScrollbar = gtk_vscrollbar_new (GTK_TEXT (moduleText)->vadj);
+	gtk_box_pack_start (GTK_BOX (hbox2), textScrollbar, FALSE, FALSE, 0);
+	gtk_widget_show (textScrollbar);
+
+
+/*
   handlebox5 = gtk_handle_box_new ();
   gtk_object_set_data (GTK_OBJECT (mainWindow), "handlebox5", handlebox5);
   gtk_widget_show (handlebox5);
   gtk_box_pack_start (GTK_BOX (hbox2), handlebox5, FALSE, FALSE, 0);
   gtk_container_border_width (GTK_CONTAINER (handlebox5), 5);
+*/
 
   searchPanel = gtk_vbox_new (FALSE, 0);
   gtk_object_set_data (GTK_OBJECT (mainWindow), "searchPanel", searchPanel);
   gtk_widget_show (searchPanel);
-  gtk_container_add (GTK_CONTAINER (handlebox5), searchPanel);
+  gtk_box_pack_start (GTK_BOX (hbox2), searchPanel, FALSE, FALSE, 0);
+//  gtk_container_add (GTK_CONTAINER (handlebox5), searchPanel);
 
   hbox4 = gtk_hbox_new (FALSE, 0);
   gtk_object_set_data (GTK_OBJECT (mainWindow), "hbox4", hbox4);
@@ -293,6 +330,23 @@ GtkWidget *MainWindow::create() {
   gtk_box_pack_start (GTK_BOX (mainPanel), statusbar1, FALSE, TRUE, 0);
 */
 
+  arrow1 = gtk_button_new_with_label ("[<]");
+  gtk_object_set_data (GTK_OBJECT (mainWindow), "arrow1", arrow1);
+  gtk_widget_show (arrow1);
+  gtk_box_pack_start (GTK_BOX (headerPanel), arrow1, FALSE, FALSE, 0);
+  gtk_signal_connect (GTK_OBJECT (arrow1), "clicked",
+                      GTK_SIGNAL_FUNC (on_arrow1_button_press_event),
+                      NULL);
+
+  arrow2 = gtk_button_new_with_label ("[>]");
+  gtk_object_set_data (GTK_OBJECT (mainWindow), "arrow2", arrow2);
+  gtk_widget_show (arrow2);
+  gtk_box_pack_start (GTK_BOX (headerPanel), arrow2, FALSE, FALSE, 0);
+  gtk_signal_connect (GTK_OBJECT (arrow2), "clicked",
+                      GTK_SIGNAL_FUNC (on_arrow2_button_press_event),
+                      NULL);
+
+
 	statusbar1 = gtk_label_new ("");
 	gtk_object_set_data (GTK_OBJECT (mainWindow), "statusbar1", statusbar1);
 	gtk_widget_show (statusbar1);
@@ -301,8 +355,9 @@ GtkWidget *MainWindow::create() {
 	gtk_misc_set_padding (GTK_MISC (statusbar1), 2, 0);
 
 
-	GTKChapDisp::__initialize();
+	GTKEntryDisp::__initialize();
 	chapDisplay = new GTKChapDisp(moduleText);
+	entryDisplay = new GTKEntryDisp(moduleText);
 
 	return mainWindow;
 }
@@ -319,7 +374,17 @@ void MainWindow::initSWORD() {
 	SWModule *curMod;
 
 	for (it = mainMgr->Modules.begin(); it != mainMgr->Modules.end(); it++) {
+		curMod = (*it).second;
+		menuChoice = gtk_menu_item_new_with_label (curMod->Name());
+		sprintf(menuName, "viewMod%d", viewNumber++);
+		gtk_object_set_data (GTK_OBJECT (mainWindow), menuName, menuChoice);
+		gtk_widget_show (menuChoice);
+		gtk_signal_connect(GTK_OBJECT (menuChoice), "activate",
+			      GTK_SIGNAL_FUNC (on_viewMod_activate),
+			      g_strdup(curMod->Name()));
+
 		if (!strcmp((*it).second->Type(), "Biblical Texts")) {
+			gtk_container_add (GTK_CONTAINER (menuView), menuChoice);
 			font = 0;
 			if ((sit = mainMgr->config->Sections.find((*it).second->Name())) != mainMgr->config->Sections.end()) {
 				if ((eit = (*sit).second.find("Font")) != (*sit).second.end()) {
@@ -327,27 +392,28 @@ void MainWindow::initSWORD() {
 				}
 			}
 //			CreateTextPane((*it).second, font);
-			curMod = (*it).second;
-
-			if (!this->curMod) 	// set currently selected module for app to first module from SWMgr
+			curMod->Disp(chapDisplay);	// set our GTKChapDisp object up for the diplayer of each Biblical Text module
+			if (!this->curMod) 	// set currently selected module for app to first module from SWMgr (Bible Texts get first preference
 				this->curMod = curMod;
-			curMod->Disp(chapDisplay);	// set our GTKChapDisp object up for the diplayer of each module
-
-			menuChoice = gtk_menu_item_new_with_label (curMod->Name());
-			sprintf(menuName, "viewMod%d", viewNumber++);
-			gtk_object_set_data (GTK_OBJECT (mainWindow), menuName, menuChoice);
-			gtk_widget_show (menuChoice);
-			gtk_container_add (GTK_CONTAINER (menuView), menuChoice);
-			gtk_signal_connect(GTK_OBJECT (menuChoice), "activate",
-				      GTK_SIGNAL_FUNC (on_viewMod_activate),
-				      g_strdup(curMod->Name()));
-
 		}
-//		if (!strcmp((*it).second->Type(), "Commentaries"))
-//			CreateCommentPane((*it).second);
-//		if (!strcmp((*it).second->Type(), "Lexicons / Dictionaries"))
-//			CreateLDPane((*it).second);
+		else	{
+			curMod->Disp(entryDisplay);	// set our GTKEntryDisp object up for the diplayer of each module other than Biblical Texts
+			if (!strcmp((*it).second->Type(), "Commentaries")) {
+				gtk_container_add (GTK_CONTAINER (menuCommentaries), menuChoice);
+	//			CreateCommentPane((*it).second);
+			}
+			if (!strcmp((*it).second->Type(), "Lexicons / Dictionaries")) {
+				gtk_container_add (GTK_CONTAINER (menuDictionaries), menuChoice);
+	//			CreateLDPane((*it).second);
+			}
+		}
+
+
 	}
+	gtk_container_add (GTK_CONTAINER (menuView), commentaries);
+	gtk_container_add (GTK_CONTAINER (menuView), dictionaries);
+	if (!this->curMod) 	// set currently selected module for app to first module from SWMgr
+		this->curMod = curMod;
 }
 
 
@@ -379,6 +445,19 @@ void MainWindow::viewModActivate(GtkMenuItem *sender, gchar *modName) {
 }
 
 
+void MainWindow::navigateButtonClicked(int direction) {
+	if (curMod) {
+		if (direction)
+			(*curMod)++;
+		else	(*curMod)--;
+		(const char *)*curMod;  // snap to closest locations
+		gchar *text = curMod->KeyText();
+		gtk_entry_set_text(GTK_ENTRY(lookupText), text);
+//		curMod->Display();
+	}
+}
+
+
 void MainWindow::searchButtonClicked() {
 	string srchText;
 	gchar *entryText;
@@ -413,8 +492,24 @@ void MainWindow::resultListSelectionChanged(GtkWidget *clist, gint row, gint col
 	}
 }
 
-GdkColor GTKChapDisp::colourBlue;
-GdkColor GTKChapDisp::colourGreen;
+GdkColor GTKEntryDisp::colourBlue;
+GdkColor GTKEntryDisp::colourGreen;
+
+char GTKEntryDisp::Display(SWModule &imodule) {
+	char tmpBuf[255];
+
+	gtk_text_set_point(GTK_TEXT(gtkText), 0);
+	gtk_text_forward_delete (GTK_TEXT (gtkText), gtk_text_get_length((GTK_TEXT(gtkText))));
+	int curPos = 0;
+	(const char *)imodule;	// snap to entry
+	gtk_text_freeze (GTK_TEXT(gtkText));
+	sprintf(tmpBuf, "[%s] ", imodule.KeyText());
+	gtk_text_insert(GTK_TEXT(gtkText), NULL, &colourBlue, NULL, tmpBuf, -1);
+	gtk_text_insert(GTK_TEXT(gtkText), NULL, &gtkText->style->black, NULL, (const char *)imodule, -1);
+	gtk_text_set_point(GTK_TEXT(gtkText), curPos);
+	gtk_text_thaw(GTK_TEXT(gtkText));
+}
+
 
 char GTKChapDisp::Display(SWModule &imodule) {
 	char tmpBuf[255];
