@@ -45,7 +45,8 @@ set_notebook_tab                       (GtkWidget       *notebook,
 
 GtkWidget* create_mainWindow (void);
 
-class GTKChapDisp : public SWDisp {
+class GTKEntryDisp : public SWDisp {
+protected:
 	GtkWidget *gtkText;
 public:
 	static GdkColor colourGreen;
@@ -55,8 +56,8 @@ public:
 
 			cmap = gdk_colormap_get_system();
 			colourGreen.red = 0;
-			colourGreen.green = 0xffff;
-			colourGreen.blue = 0;
+			colourGreen.green = 0x00ff;
+			colourGreen.blue = 0xffff;
 			colourBlue.red = 0;
 			colourBlue.green = 0;
 			colourBlue.blue = 0xffff;
@@ -67,7 +68,13 @@ public:
 			  g_error("couldn't allocate colour");
 			}
 	}
-	GTKChapDisp(GtkWidget *gtkText) { this->gtkText = gtkText; }
+	GTKEntryDisp(GtkWidget *gtkText) { this->gtkText = gtkText; }
+	virtual char Display(SWModule &imodule);
+};
+
+class GTKChapDisp : public GTKEntryDisp {
+public:
+	GTKChapDisp(GtkWidget *gtkText) : GTKEntryDisp(gtkText) {}
 	virtual char Display(SWModule &imodule);
 };
 
@@ -84,6 +91,10 @@ class MainWindow {
 	GtkWidget *Help;
 	GtkWidget *menu14;
 	GtkWidget *menuView;
+	GtkWidget *menuCommentaries;
+	GtkWidget *menuDictionaries;
+	GtkWidget *commentaries;
+	GtkWidget *dictionaries;
 	GtkWidget *About;
 	GtkWidget *handlebox4;
 	GtkWidget *hbox6;
@@ -106,10 +117,16 @@ class MainWindow {
 	GtkWidget *caseSensitive;
 	GtkWidget *resultList;
 	GtkWidget *statusbar1;
+	GtkWidget *textScrolledWindow;
+	GtkWidget *textScrollbar;
+	GtkWidget *arrow1;
+	GtkWidget *arrow2;
+
 
 	SWMgr *mainMgr;
 	SWModule *curMod;
 	SWDisp *chapDisplay;
+	SWDisp *entryDisplay;
 public:
 	MainWindow();
 	~MainWindow();
@@ -118,7 +135,12 @@ public:
 	void lookupTextChanged();
 	void viewModActivate(GtkMenuItem *sender, gchar *modName);
 	void searchButtonClicked();
+	void navigateButtonClicked(int direction);
 	void resultListSelectionChanged(GtkWidget *clist, gint row, gint column, GdkEventButton *event, gpointer data);
 };
 
+
 extern MainWindow *cheatahWindow;
+
+
+
