@@ -310,7 +310,7 @@ void __fastcall TForm1::FormShow(TObject *Sender)
 		FileMgr::systemFileMgr.maxFiles = maxFiles;
 	}
 
-	DefaultVSKey = "Genesis 1:1";
+	DefaultVSKey = TOP;
 	cbBook->Clear();
 	while (!DefaultVSKey.Error()) {
 		s1 = (const char *)DefaultVSKey;
@@ -409,8 +409,15 @@ void __fastcall TForm1::SearchPokeData(TObject *Sender)
 //---------------------------------------------------------------------------
 void __fastcall TForm1::UpDown3Click(TObject *Sender, TUDBtnType Button)
 {
-	cbBook->ItemIndex += (Button == btNext) ? -1 : 1;
-	btnLookupClick(Sender);	
+	ModMap::iterator it;
+	
+	it = mainmgr->Modules.find(PageControl3->ActivePage->Caption.c_str());
+	if (it != mainmgr->Modules.end()) {
+		if (Button == btNext)
+			(*((*it).second))++;
+		else	(*((*it).second))--;
+		DictKeyEdit->Text = ((*it).second)->KeyText();
+	}
 }
 //---------------------------------------------------------------------------
 void __fastcall TForm1::UpDown1Click(TObject *Sender, TUDBtnType Button)
@@ -799,3 +806,4 @@ void __fastcall TForm1::LinktoVerse1Click(TObject *Sender)
 }
 //---------------------------------------------------------------------------
 
+
