@@ -1,5 +1,22 @@
 /******************************************************************************
  * canon.h - Canonical text information to be included by VerseKey.cpp
+ *
+ * $Id: canon.h,v 1.2 1998/12/27 01:41:58 troy Exp $
+ *
+ * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
+ *	CrossWire Bible Society
+ *	P. O. Box 2528
+ *	Tempe, AZ  85280-2528
+ *
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License as published by the
+ * Free Software Foundation version 2.
+ *
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ *
  */
 
 /******************************************************************************
@@ -230,7 +247,7 @@ struct abbrev VerseKey::abbrevs[] = {
 	{"PSALMS", 19}, //    Psalms
 	{"PROVERBS", 20}, //    Proverbs
 	{"REVELATION OF JOHN", 66}, //     Revelation
-	{"ROMANS", 46}, //    Romans
+	{"ROMANS", 45}, //    Romans
 	{"RUTH", 8}, //    Ruth
 	{"SONG OF SOLOMON", 22}, //     Song of Solomon
 	{"SONG OF SONGS", 22}, //     Song of Solomon
