@@ -1,14 +1,15 @@
 /******************************************************************************
  *  rawverse.h   - code for class 'RawVerse'- a module that reads raw text
- *				files:  ot and nt using indexs ??.bks ??.cps ??.vss
- *				and provides lookup and parsing functions based on
- *				class VerseKey
+ *			files:  ot and nt using indexs ??.bks ??.cps ??.vss
+ *			and provides lookup and parsing functions based on
+ *			class VerseKey
  */
 
 #ifndef RAWVERSE_H
 #define RAWVERSE_H
 
 #include <filemgr.h>
+#include <fcntl.h>
 
 class RawVerse {
 	static int instance;	// number of instantiated RawVerse objects or derivitives
@@ -24,7 +25,7 @@ protected:
 	
 public:
 	char nl;
-	RawVerse(const char *ipath);
+	RawVerse(const char *ipath, int fileMode = O_RDONLY);
 	virtual ~RawVerse();
 };
 
