@@ -1,3 +1,24 @@
+/******************************************************************************
+ *  swcomprs.h   - definition of Class SWCompress used for data compression
+ *
+ * $Id: swcomprs.h,v 1.2 1998/12/27 01:41:59 troy Exp $
+ *
+ * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
+ *	CrossWire Bible Society
+ *	P. O. Box 2528
+ *	Tempe, AZ  85280-2528
+ *
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License as published by the
+ * Free Software Foundation version 2.
+ *
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ *
+ */
+
 #ifndef SWCOMPRS_H
 #define SWCOMPRS_H
 
