@@ -1,3 +1,25 @@
+/******************************************************************************
+ *  swdisprtfchap.h	- definition of class SWDispRTFChap, an SWDisp used to
+ *				display an entire chapter in Rich Text Format
+ *
+ * $Id: swdisprtfchap.h,v 1.3 1999/01/06 21:53:54 troy Exp $
+ *
+ * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
+ *	CrossWire Bible Society
+ *	P. O. Box 2528
+ *	Tempe, AZ  85280-2528
+ *
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License as published by the
+ * Free Software Foundation version 2.
+ *
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ *
+ */
+
 //---------------------------------------------------------------------------
 #ifndef swdisprtfchapH
 #define swdisprtfchapH
