@@ -1,7 +1,24 @@
 /******************************************************************************
- *  swkey.h   - code for base class 'swkey'.  swkey is the basis for all
- *	        types of keys for indexing into modules (e.g. verse, word,
- *		place, etc.)
+ *  swkey.h	- code for base class 'swkey'.  swkey is the basis for all
+ *				types of keys for indexing into modules (e.g. verse, word,
+ *				place, etc.)
+ *
+ * $Id: swkey.h,v 1.2 1998/12/27 01:41:59 troy Exp $
+ *
+ * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
+ *	CrossWire Bible Society
+ *	P. O. Box 2528
+ *	Tempe, AZ  85280-2528
+ *
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License as published by the
+ * Free Software Foundation version 2.
+ *
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ *
  */
 
 #ifndef SWKEY_H
