@@ -3,7 +3,10 @@
 #pragma hdrstop
 USERES("Project1.res");
 USEFORM("Unit1.cpp", Form1);
-USELIB("..\frontend\windoze\CBuilder3\BibleCS\swordlib.lib");
+USEUNIT("..\keys\versekey.cpp");
+USEUNIT("..\keys\swkey.cpp");
+USEUNIT("..\keys\swlstkey.cpp");
+USEUNIT("..\utilfuns\utilstr.cpp");
 //---------------------------------------------------------------------------
 WINAPI WinMain(HINSTANCE, HINSTANCE, LPSTR, int)
 {
