@@ -434,19 +434,19 @@ VerseKey::operator const char *() const
 SWKey &VerseKey::operator =(POSITION p)
 {
 	switch (p) {
-	case 1:	// P_TOP won't compile under GCC!
+	case POS_TOP:
 		testament = 0;
 		book      = 0;
 		chapter   = 0;
 		verse     = 0;
 		break;
-	case 2:	// P_BOTTOM won't compile under GCC!
+	case POS_BOTTOM:
 		testament = 3;
 		break;
 	} 
 	Normalize(1);
 	Error();	// clear error from normalize
-	return SWKey::operator=(p);
+	return *this;
 }
 
 
